@@ -15,6 +15,19 @@ def test_base_pyproject(cwd):
     assert "sphinx" in [dep.name for dep in universal.optional_dependencies["doc"]]
 
 
+def test_empty_pyproject(tmp_path):
+    pyproject_toml = tmp_path / "pyproject.toml"
+    with pyproject_toml.open(mode="w") as f:
+        f.write("[spam]")
+    pyproject = PyProject(tmp_path, "pytoolconfig", [])
+    pyproject.parse()
+    pyproject.universalconfig()
+
+    with pyproject_toml.open(mode="w") as f:
+        pass
+    pyproject.parse()
+
+
 def test_base_ini(cwd):
     config = IniConfig(cwd, "test_config.ini", "pytoolconfig").parse()
     assert config["formatter"] == "yapf"
